##  Benefits
  * Find all SaaS applications that are used in your organization.
  * Fully automate adding SaaS applications to SAP LeanIX, ensuring your inventory stays up to date and complete.
  * Enrich existing application fact sheets with information from the reference catalog, including description, product category, SSO, and hosting.
  * Detect multiple instances of the same SaaS in different SSOs and rationalize or manage portfolios better.
  * Eliminate shadow IT and business-managed IT.
  * Mitigate security and compliance risks.


**Note**
The SaaS discovery feature in SAP LeanIX does not provide insight into cost, adoptions, contracts, and other SaaS specifics.
